"use strict";
/**
 * @file 基于 vscode 标准 TreeDataProvider 接口实现的扩展，除了 get，提供了 set 方法。
 * @author weijiaxun <weijiaxun@baidu.com>
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = __importStar(require("vscode"));
const ExtendedTreeItem_1 = __importDefault(require("./ExtendedTreeItem"));
class ExtendedTreeDataProvider {
    constructor() {
        this._data = { children: [] };
        this._onDidChangeTreeData = new vscode.EventEmitter();
        this.onDidChangeTreeData = this._onDidChangeTreeData.event;
    }
    getChildren(element) {
        const children = element ? element.children : this._data.children;
        return children;
    }
    getParent(element) {
        return element.parent;
    }
    getTreeItem(element) {
        return element.value;
    }
    createTreeItem(value) {
        const item = new ExtendedTreeItem_1.default(value);
        item.onDidChange(() => {
            this._onDidChangeTreeData.fire(item);
        });
        return item;
    }
    appendChildToRoot(element) {
        element.parent = null;
        this._data.children.push(element);
        this._onDidChangeTreeData.fire();
    }
    removeChildFromRoot(element) {
        this._data.children = this._data.children.filter(item => item !== element);
        this._onDidChangeTreeData.fire();
    }
    insertInRootBefore(element, beforeElement) {
        const existingIndex = this._data.children.findIndex(item => item === element);
        const index = this._data.children.findIndex(item => item === beforeElement);
        if (existingIndex > -1) {
            // reorder the element instead of inserting a new one
            this._data.children.splice(existingIndex, 1);
        }
        this._data.children.splice(index + 1, 0, element);
        this._onDidChangeTreeData.fire();
    }
}
exports.default = ExtendedTreeDataProvider;
//# sourceMappingURL=ExtendedTreeDataProvider.js.map